==> poi-ooxml-3.12-sources.jar: org/apache/poi/xslf/usermodel/DrawingTable.java <==
/* ====================================================================
   Licensed to the Apache Software Foundation (ASF) under one or more
   contributor license agreements.  See the NOTICE file distributed with
   this work for additional information regarding copyright ownership.
   The ASF licenses this file to You under the Apache License, Version 2.0
   (the "License"); you may not use this file except in compliance with
   the License.  You may obtain a copy of the License at

       http://www.apache.org/licenses/LICENSE-2.0

   Unless required by applicable law or agreed to in writing, software
   distributed under the License is distributed on an "AS IS" BASIS,
   WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
   See the License for the specific language governing permissions and
   limitations under the License.
==================================================================== */

package org.apache.poi.xslf.usermodel;

import org.openxmlformats.schemas.drawingml.x2006.main.CTTable;
import org.openxmlformats.schemas.drawingml.x2006.main.CTTableRow;

public class DrawingTable {
    private final CTTable table;

    public DrawingTable(CTTable table) {
        this.table = table;
    }

    @SuppressWarnings("deprecation")
    public DrawingTableRow[] getRows() {
        CTTableRow[] ctTableRows = table.getTrArray();
        DrawingTableRow[] o = new DrawingTableRow[ctTableRows.length];

        for (int i=0; i<o.length; i++) {
            o[i] = new DrawingTableRow(ctTableRows[i]);
        }

        return o;
    }
}

==> poi-ooxml-3.17-sources.jar: org/apache/poi/xslf/usermodel/DrawingTable.java <==
/* ====================================================================
   Licensed to the Apache Software Foundation (ASF) under one or more
   contributor license agreements.  See the NOTICE file distributed with
   this work for additional information regarding copyright ownership.
   The ASF licenses this file to You under the Apache License, Version 2.0
   (the "License"); you may not use this file except in compliance with
   the License.  You may obtain a copy of the License at

       http://www.apache.org/licenses/LICENSE-2.0

   Unless required by applicable law or agreed to in writing, software
   distributed under the License is distributed on an "AS IS" BASIS,
   WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
   See the License for the specific language governing permissions and
   limitations under the License.
==================================================================== */

package org.apache.poi.xslf.usermodel;

import org.apache.poi.util.Removal;
import org.openxmlformats.schemas.drawingml.x2006.main.CTTable;
import org.openxmlformats.schemas.drawingml.x2006.main.CTTableRow;

/*
 * @deprecated POI 3.16 beta 1. use {@link XSLFTable} instead
 */
@Removal(version="3.18")
public class DrawingTable {
    private final CTTable table;

    public DrawingTable(CTTable table) {
        this.table = table;
    }

    public DrawingTableRow[] getRows() {
        CTTableRow[] ctTableRows = table.getTrArray();
        DrawingTableRow[] o = new DrawingTableRow[ctTableRows.length];

        for (int i=0; i<o.length; i++) {
            o[i] = new DrawingTableRow(ctTableRows[i]);
        }

        return o;
    }
}
